==> lxqt-notificationd_1.2.0.orig.tar.xz: lxqt-notificationd-1.2.0/config/translations/lxqt-config-notificationd_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="67"/>
        <source>Sizes</source>
        <translation>大小</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="75"/>
        <source>Width:</source>
        <translation>宽度:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="82"/>
        <location filename="../advancedsettings.ui" line="106"/>
        <source> px</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="99"/>
        <source>Spacing:</source>
        <translation>间距:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="118"/>
        <source>Duration</source>
        <translation>持续时间</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="130"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>有些通知有自己的持续时间。</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="142"/>
        <source>Default duration:</source>
        <translation>默认持续时间:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="149"/>
        <source> sec</source>
        <translation> 秒</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="177"/>
        <source>Screen</source>
        <translation>屏幕</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="183"/>
        <source>When unchecked the notification will always show on primary screen</source>
        <translation>当没有检测到时，该通知会在主屏幕一直显示</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="186"/>
        <source>Show notifications on screen with the mouse</source>
        <translation>使用鼠标时在屏幕上显示通知</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="196"/>
        <source>Do Not Disturb</source>
        <translation>免打扰服务</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="202"/>
        <source>Only save notifications</source>
        <translation>只保存通知</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Unattended Notifications</source>
        <translation>未读通知</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="25"/>
        <source>How many to save:</source>
        <translation>要保存的数量：</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="39"/>
        <location filename="../advancedsettings.ui" line="49"/>
        <source>Application name is on the top of notification.</source>
        <translation>应用程序名称位于通知顶部。</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="42"/>
        <source>Ignore these applications:</source>
        <translation>忽略这些应用程序：</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="52"/>
        <source>app1,app2,app3</source>
        <translation>程序1，程序2，程序3</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="17"/>
        <source>Position on screen</source>
        <translation>在屏幕上的位置</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="176"/>
        <source>Preview</source>
        <translation>预览</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="63"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
Keep trying to connect…</source>
        <translation>&lt;b&gt;警告：&lt;/b&gt; 通知守护进程响应缓慢。
继续尝试连接 …</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="72"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;警告：&lt;/b&gt; 没有运行通知守护进程
已使用默认值。</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="75"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;警告：&lt;/b&gt; 正在运行第三方的通知守护进程（%1）
这些设置不会有任何效果！</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="137"/>
        <source>at top left</source>
        <translation>在左上角</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="139"/>
        <source>at top center</source>
        <translation>在顶部中心</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="141"/>
        <source>at top right</source>
        <translation>在右上方</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="143"/>
        <source>at center left</source>
        <translation>在中间偏左的位置</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="145"/>
        <source>at center right</source>
        <translation>在中间右侧</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="147"/>
        <source>at bottom left</source>
        <translation>在左下方</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="149"/>
        <source>at bottom center</source>
        <translation>在底部中心位置</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="151"/>
        <source>at bottom right</source>
        <translation>在右下方</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="153"/>
        <source>Notification demo </source>
        <translation>通知示例 </translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="154"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>这是一则测试通知
 LXQt 上的所有通知都会出现于此。</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Desktop Notifications</source>
        <translation>桌面通知</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>General Settings</source>
        <translation>通用设置</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Position</source>
        <translation>位置</translation>
    </message>
</context>
</TS>

==> lxqt-notificationd_2.1.1.orig.tar.xz: lxqt-notificationd-2.1.1/config/translations/lxqt-config-notificationd_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="67"/>
        <source>Duration</source>
        <translation>持续时间</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="79"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>有些通知有自己的持续时间。</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="91"/>
        <source>Default duration:</source>
        <translation>默认持续时间:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="98"/>
        <source> sec</source>
        <translation> 秒</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="126"/>
        <source>Screen</source>
        <translation>屏幕</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="132"/>
        <source>When unchecked the notification will always show on primary screen</source>
        <translation>当没有检测到时，该通知会在主屏幕一直显示</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="135"/>
        <source>Show notifications on screen with the mouse</source>
        <translation>使用鼠标时在屏幕上显示通知</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="145"/>
        <source>Do Not Disturb</source>
        <translation>免打扰服务</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="151"/>
        <source>Only save notifications</source>
        <translation>只保存通知</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Unattended Notifications</source>
        <translation>未读通知</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="25"/>
        <source>How many to save:</source>
        <translation>要保存的数量：</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="39"/>
        <location filename="../advancedsettings.ui" line="49"/>
        <source>Application name is on the top of notification.</source>
        <translation>应用程序名称位于通知顶部。</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="42"/>
        <source>Ignore these applications:</source>
        <translation>忽略这些应用程序：</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="52"/>
        <source>app1,app2,app3</source>
        <translation>程序1，程序2，程序3</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="17"/>
        <source>Sizes</source>
        <translation>大小</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="25"/>
        <source>Width:</source>
        <translation>宽度:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="32"/>
        <location filename="../basicsettings.ui" line="56"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Spacing:</source>
        <translation>间距:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="68"/>
        <source>Position on screen</source>
        <translation>在屏幕上的位置</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="227"/>
        <source>Preview</source>
        <translation>预览</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="65"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
Keep trying to connect…</source>
        <translation>&lt;b&gt;警告：&lt;/b&gt; 通知守护进程响应缓慢。
继续尝试连接 …</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="74"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;警告：&lt;/b&gt; 没有运行通知守护进程
已使用默认值。</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="77"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;警告：&lt;/b&gt; 正在运行第三方的通知守护进程（%1）
这些设置不会有任何效果！</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="142"/>
        <source>at top left</source>
        <translation>在左上角</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="144"/>
        <source>at top center</source>
        <translation>在顶部中心</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="146"/>
        <source>at top right</source>
        <translation>在右上方</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="148"/>
        <source>at center left</source>
        <translation>在中间偏左的位置</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="150"/>
        <source>at center right</source>
        <translation>在中间右侧</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="152"/>
        <source>at bottom left</source>
        <translation>在左下方</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="154"/>
        <source>at bottom center</source>
        <translation>在底部中心位置</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="156"/>
        <source>at bottom right</source>
        <translation>在右下方</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="158"/>
        <source>Notification demo </source>
        <translation>通知示例 </translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="159"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>这是一则测试通知
 LXQt 上的所有通知都会出现于此。</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Desktop Notifications</source>
        <translation>桌面通知</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>General Settings</source>
        <translation>通用设置</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Appearance</source>
        <translation>外观</translation>
    </message>
</context>
</TS>
